@@ -45,15 +45,8 @@ rpubsUpload <- function(title,
                         id = NULL,
                         properties = list()) {
 
-  # validate inputs
-  if (!is.character(title))
-    stop("title must be specified")
-  if (nzchar(title) == FALSE)
-    stop("title pmust be a non-empty string")
-  if (!is.character(contentFile))
-    stop("contentFile parameter must be specified")
-  if (!file.exists(contentFile))
-    stop("specified contentFile does not exist")
+  check_string(title, allow_empty = FALSE)
+  check_file(contentFile)
   if (!is.list(properties))
     stop("properties paramater must be a named list")
 
@@ -70,27 +63,21 @@ rpubsUpload <- function(title,
                            properties = list()) {
 
     # build package.json
-    properties$title = title
+    properties$title <- title
     packageJson <- toJSON(properties)
 
     # create a tempdir to build the package in and copy the files to it
     fileSep <- .Platform$file.sep
-    packageDir <- tempfile()
-    dir.create(packageDir)
+    packageDir <- dirCreate(tempfile())
     packageFile <- function(fileName) {
       paste(packageDir, fileName, sep = fileSep)
     }
     writeLines(packageJson, packageFile("package.json"))
     file.copy(contentFile, packageFile("index.html"))
 
-    # switch to the package dir for building
-    oldWd <- getwd()
-    setwd(packageDir)
-    on.exit(setwd(oldWd))
-
     # create the tarball
     tarfile <- tempfile("package", fileext = ".tar.gz")
-    utils::tar(tarfile, files = ".", compression = "gzip", tar = "internal")
+    writeBundle(packageDir, tarfile)
 
     # return the full path to the tarball
     return(tarfile)
@@ -111,9 +98,9 @@ rpubsUpload <- function(title,
     method <- "PUT"
   }
 
-  # use https if using RCurl, and vanilla HTTP otherwise
+  # use https if using a curl R package, and vanilla HTTP otherwise
   http <- httpFunction()
-  if (identical(http, httpRCurl)) {
+  if (identical(http, httpRCurl) || identical(http, httpLibCurl)) {
     protocol <- "https"
     port <- 443
   } else {
@@ -122,8 +109,14 @@ rpubsUpload <- function(title,
   }
 
   # send the request
-  result <- http(protocol, "api.rpubs.com", port, method, path, headers,
-                 "application/x-compressed", file = packageFile)
+  result <- http(protocol = protocol,
+                 host = "api.rpubs.com",
+                 port = port,
+                 method = method,
+                 path = path,
+                 headers = headers,
+                 contentType = "application/x-compressed",
+                 contentFile = packageFile)
 
   # check for success
   succeeded <- FALSE
@@ -153,7 +146,7 @@ rpubsUpload <- function(title,
 
     rpubsRec <- deploymentRecord(recordName, "", "", "rpubs", "rpubs.com", "rpubs.com", id, id,
                                  url, as.numeric(Sys.time()))
-    rpubsRecFile <- deploymentFile(recordSource, recordName, "rpubs",
+    rpubsRecFile <- deploymentConfigFile(recordSource, recordName, "rpubs",
                                    "rpubs.com")
     write.dcf(rpubsRec, rpubsRecFile, width = 4096)
 
@@ -168,4 +161,3 @@ rpubsUpload <- function(title,
     return(list(error = content))
   }
 }
-
